@@ -1,8 +1,8 @@
 # frozen_string_literal: true
 
-require 'test_helper'
+require_relative '../test_helper'
 
-class AESDecrypterTest < MiniTest::Test
+class AESDecrypterTest < Minitest::Test
   def setup
     @decrypter256 = ::Zip::AESDecrypter.new('password', ::Zip::AESEncryption::STRENGTH_256_BIT)
     @decrypter128 = ::Zip::AESDecrypter.new('password', ::Zip::AESEncryption::STRENGTH_128_BIT)
