@@ -1,9 +1,10 @@
 # frozen_string_literal: true
 
-require 'test_helper'
+require_relative '../test_helper'
+
 require 'zip/ioextras'
 
-class FakeIOTest < MiniTest::Test
+class FakeIOTest < Minitest::Test
   class FakeIOUsingClass
     include ::Zip::IOExtras::FakeIO
   end
