@@ -1,7 +1,9 @@
 # frozen_string_literal: true
 
-require 'test_helper'
-class PassThruDecompressorTest < MiniTest::Test
+require_relative 'test_helper'
+require_relative 'helpers/decompressor_tests'
+
+class PassThruDecompressorTest < Minitest::Test
   include DecompressorTests
 
   def setup
